from peewee import CompositeKey, DateTimeField, FloatField, IntegerField, Model


class Met10Mindata(Model):
    airressuresensorzerooffset = IntegerField(null=True)
    anemometer1_avg_freq = IntegerField(null=True)
    anemometer1_corrgain = FloatField(null=True)
    anemometer1_corroffset = FloatField(null=True)
    anemometer1_freq = FloatField(null=True)
    anemometer1_offset = FloatField(null=True)
    anemometer2_avg_freq = IntegerField(null=True)
    anemometer2_corrgain = FloatField(null=True)
    anemometer2_corroffset = FloatField(null=True)
    anemometer2_freq = FloatField(null=True)
    anemometer2_offset = FloatField(null=True)
    avg_ambienttemp = IntegerField(null=True)
    avg_humidity = IntegerField(null=True)
    avg_precipitation = FloatField(null=True)
    avg_pressure = IntegerField(null=True)
    avg_raindetection = IntegerField(null=True)
    avg_winddirection1 = IntegerField(null=True)
    avg_winddirection2 = IntegerField(null=True)
    avg_windspeed1 = FloatField(null=True)
    avg_windspeed2 = FloatField(null=True)
    avgicelevel = FloatField(null=True)
    distanceairpress = IntegerField(null=True)
    id = IntegerField(null=True)
    max_ambienttemp = IntegerField(null=True)
    max_humidity = IntegerField(null=True)
    max_precipitation = FloatField(null=True)
    max_pressure = IntegerField(null=True)
    max_raindetection = IntegerField(null=True)
    max_winddirection1 = IntegerField(null=True)
    max_winddirection2 = IntegerField(null=True)
    max_windspeed1 = FloatField(null=True)
    max_windspeed2 = FloatField(null=True)
    maxicelevel = FloatField(null=True)
    met_id = IntegerField()
    min_ambienttemp = IntegerField(null=True)
    min_humidity = IntegerField(null=True)
    min_precipitation = FloatField(null=True)
    min_pressure = IntegerField(null=True)
    min_raindetection = IntegerField(null=True)
    min_winddirection1 = IntegerField(null=True)
    min_winddirection2 = IntegerField(null=True)
    min_windspeed1 = FloatField(null=True)
    min_windspeed2 = FloatField(null=True)
    minicelevel = FloatField(null=True)
    pctimestamp = DateTimeField()
    ppmtimestamp = DateTimeField(null=True)
    pressure_avg_freq = IntegerField(null=True)
    ttimestamp = DateTimeField(null=True)
    var_ambienttemp = IntegerField(null=True)
    var_humidity = IntegerField(null=True)
    var_precipitation = FloatField(null=True)
    var_pressure = IntegerField(null=True)
    var_raindetection = IntegerField(null=True)
    var_winddirection1 = IntegerField(null=True)
    var_winddirection2 = IntegerField(null=True)
    var_windspeed1 = FloatField(null=True)
    var_windspeed2 = FloatField(null=True)
    varicelevel = IntegerField(null=True)

    class Meta:
        table_name = "met_10mindata"
        indexes = ((("met_id", "pctimestamp"), True),)
        primary_key = CompositeKey("met_id", "pctimestamp")
