from peewee import CompositeKey, DateTimeField, FloatField, IntegerField, Model


class PLCData(Model):
    aero_id = IntegerField()
    pctimestamp = DateTimeField()
    rpm = FloatField(null=True)
    s10_hz = FloatField(null=True)
    s10_mms = FloatField(null=True)
    s10_ua = FloatField(null=True)
    s11_hz = FloatField(null=True)
    s11_mms = FloatField(null=True)
    s11_ua = FloatField(null=True)
    s12_hz = FloatField(null=True)
    s12_mms = FloatField(null=True)
    s12_ua = FloatField(null=True)
    s1_hz = FloatField(null=True)
    s1_mms = FloatField(null=True)
    s1_ua = FloatField(null=True)
    s2_hz = FloatField(null=True)
    s2_mms = FloatField(null=True)
    s2_ua = FloatField(null=True)
    s3_hz = FloatField(null=True)
    s3_mms = FloatField(null=True)
    s3_ua = FloatField(null=True)
    s4_hz = FloatField(null=True)
    s4_mms = FloatField(null=True)
    s4_ua = FloatField(null=True)
    s5_hz = FloatField(null=True)
    s5_mms = FloatField(null=True)
    s5_ua = FloatField(null=True)
    s6_hz = FloatField(null=True)
    s6_mms = FloatField(null=True)
    s6_ua = FloatField(null=True)
    s7_hz = FloatField(null=True)
    s7_mms = FloatField(null=True)
    s7_ua = FloatField(null=True)
    s8_hz = FloatField(null=True)
    s8_mms = FloatField(null=True)
    s8_ua = FloatField(null=True)
    s9_hz = FloatField(null=True)
    s9_mms = FloatField(null=True)
    s9_ua = FloatField(null=True)

    class Meta:
        table_name = "plc_data"
        indexes = ((("aero_id", "pctimestamp"), True),)
        primary_key = CompositeKey("aero_id", "pctimestamp")
