from peewee import CompositeKey, DateTimeField, FloatField, IntegerField, Model


class Magana10Mindata(Model):
    aero_id = IntegerField()
    count_consumedpower = FloatField(null=True)
    count_consumedreactivepow = FloatField(null=True)
    count_engagementsbypasscont = IntegerField(null=True)
    count_engagementscomp1 = IntegerField(null=True)
    count_engagementscomp10 = IntegerField(null=True)
    count_engagementscomp2 = IntegerField(null=True)
    count_engagementscomp3 = IntegerField(null=True)
    count_engagementscomp4 = IntegerField(null=True)
    count_engagementscomp5 = IntegerField(null=True)
    count_engagementscomp6 = IntegerField(null=True)
    count_engagementscomp7 = IntegerField(null=True)
    count_engagementscomp8 = IntegerField(null=True)
    count_engagementscomp9 = IntegerField(null=True)
    count_engagementscontrolpanelfan = IntegerField(null=True)
    count_engagementscontrolpanelheat = IntegerField(null=True)
    count_engagementsg1_g2 = IntegerField(null=True)
    count_engagementsg1cont = IntegerField(null=True)
    count_engagementsg2_g1 = IntegerField(null=True)
    count_engagementsg2cont = IntegerField(null=True)
    count_engagementsgearheat = IntegerField(null=True)
    count_engagementsgearoilcoolpump = IntegerField(null=True)
    count_engagementsgearoilpump = IntegerField(null=True)
    count_engagementsgeneratorheat = IntegerField(null=True)
    count_engagementsheattopbox = IntegerField(null=True)
    count_engagementslubricationpump = IntegerField(null=True)
    count_engagementsmainbearingpump = IntegerField(null=True)
    count_engagementsmainpanelfan = IntegerField(null=True)
    count_engagementsmainpanelheat = IntegerField(null=True)
    count_engagementsnacellefan = IntegerField(null=True)
    count_engagementsnacellefanheat = IntegerField(null=True)
    count_engagementsnacelleheat1 = IntegerField(null=True)
    count_engagementsnacelleheat2 = IntegerField(null=True)
    count_engagementsofflinefilterpump = IntegerField(null=True)
    count_engagementsphasecompfan = IntegerField(null=True)
    count_engagementsphasecompheat = IntegerField(null=True)
    count_engagementspitchfeederpump = IntegerField(null=True)
    count_engagementspitchmainpump = IntegerField(null=True)
    count_engagementsshaftbrakepump = IntegerField(null=True)
    count_engagementsthyristor = IntegerField(null=True)
    count_engagementsthyristorfan = IntegerField(null=True)
    count_engagementstipbrakepump = IntegerField(null=True)
    count_engagementstransformerfan = IntegerField(null=True)
    count_engagementswaterpump = IntegerField(null=True)
    count_engagementswaterpumpgearbox = IntegerField(null=True)
    count_engagementswaterpumpgen = IntegerField(null=True)
    count_engagementswindsensorheat = IntegerField(null=True)
    count_engagementsyambrakepump = IntegerField(null=True)
    count_engagementsyawccw = IntegerField(null=True)
    count_engagementsyawcw = IntegerField(null=True)
    count_hoursengagedcomp1 = FloatField(null=True)
    count_hoursengagedcomp10 = FloatField(null=True)
    count_hoursengagedcomp2 = FloatField(null=True)
    count_hoursengagedcomp3 = FloatField(null=True)
    count_hoursengagedcomp4 = FloatField(null=True)
    count_hoursengagedcomp5 = FloatField(null=True)
    count_hoursengagedcomp6 = FloatField(null=True)
    count_hoursengagedcomp7 = FloatField(null=True)
    count_hoursengagedcomp8 = FloatField(null=True)
    count_hoursengagedcomp9 = FloatField(null=True)
    count_producedpower = FloatField(null=True)
    count_producedpowergen1 = FloatField(null=True)
    count_producedpowergen2 = FloatField(null=True)
    count_t1 = FloatField(null=True)
    count_t2 = FloatField(null=True)
    count_t3 = FloatField(null=True)
    count_timeconnectedtogrid = FloatField(null=True)
    count_timeengagedbypasscont = FloatField(null=True)
    count_timeengagedcontrolpanelfan = FloatField(null=True)
    count_timeengagedcontrolpanelheat = FloatField(null=True)
    count_timeengagedg1cont = FloatField(null=True)
    count_timeengagedg2cont = FloatField(null=True)
    count_timeengagedgearheat = FloatField(null=True)
    count_timeengagedgearoilcoolpump = FloatField(null=True)
    count_timeengagedgearoilpump = FloatField(null=True)
    count_timeengagedgen1 = FloatField(null=True)
    count_timeengagedgen2 = FloatField(null=True)
    count_timeengagedgeneratorheat = FloatField(null=True)
    count_timeengagedheattopbox = FloatField(null=True)
    count_timeengagedlubricationpump = FloatField(null=True)
    count_timeengagedmainbearingpump = FloatField(null=True)
    count_timeengagedmainpanelfan = FloatField(null=True)
    count_timeengagedmainpanelheat = FloatField(null=True)
    count_timeengagednacellefan = FloatField(null=True)
    count_timeengagednacellefanheat = FloatField(null=True)
    count_timeengagednacelleheat1 = FloatField(null=True)
    count_timeengagednacelleheat2 = FloatField(null=True)
    count_timeengagedofflinefilterpump = FloatField(null=True)
    count_timeengagedphasecompfan = FloatField(null=True)
    count_timeengagedphasecompheat = FloatField(null=True)
    count_timeengagedpitchfeederpump = FloatField(null=True)
    count_timeengagedpitchmainpump = FloatField(null=True)
    count_timeengagedshaftbrakepump = FloatField(null=True)
    count_timeengagedthyristor = FloatField(null=True)
    count_timeengagedthyristorfan = FloatField(null=True)
    count_timeengagedtipbrakepump = FloatField(null=True)
    count_timeengagedtransformerfan = FloatField(null=True)
    count_timeengagedwaterpump = FloatField(null=True)
    count_timeengagedwaterpumpgearbox = FloatField(null=True)
    count_timeengagedwaterpumpgen = FloatField(null=True)
    count_timeengagedwindsensorheat = FloatField(null=True)
    count_timeengagedyambrakepump = FloatField(null=True)
    count_timeengagedyawccw = FloatField(null=True)
    count_timeengagedyawcw = FloatField(null=True)
    count_timeinservice = FloatField(null=True)
    count_timeongrid = FloatField(null=True)
    count_timepoweron = IntegerField(null=True)
    count_timeready = FloatField(null=True)
    count_timewitherror = FloatField(null=True)
    count_timewithwarning = FloatField(null=True)
    countsecondsbrakereleased = IntegerField(null=True)
    countsecondseventcodenotzero = IntegerField(null=True)
    countsecondsgeneratorcutin = IntegerField(null=True)
    countsecondsinthis10minper = IntegerField(null=True)
    grid_avg_activepower = FloatField(null=True)
    grid_avg_currentl1 = IntegerField(null=True)
    grid_avg_currentl2 = IntegerField(null=True)
    grid_avg_currentl3 = IntegerField(null=True)
    grid_avg_freqency = FloatField(null=True)
    grid_avg_reactivepower = FloatField(null=True)
    grid_avg_voltagel1 = IntegerField(null=True)
    grid_avg_voltagel2 = IntegerField(null=True)
    grid_avg_voltagel3 = IntegerField(null=True)
    grid_max_activepower = FloatField(null=True)
    grid_max_currentl1 = IntegerField(null=True)
    grid_max_currentl2 = IntegerField(null=True)
    grid_max_currentl3 = IntegerField(null=True)
    grid_max_freqency = FloatField(null=True)
    grid_max_reactivepower = FloatField(null=True)
    grid_max_voltagel1 = IntegerField(null=True)
    grid_max_voltagel2 = IntegerField(null=True)
    grid_max_voltagel3 = IntegerField(null=True)
    grid_min_activepower = FloatField(null=True)
    grid_min_currentl1 = IntegerField(null=True)
    grid_min_currentl2 = IntegerField(null=True)
    grid_min_currentl3 = IntegerField(null=True)
    grid_min_freqency = FloatField(null=True)
    grid_min_reactivepower = FloatField(null=True)
    grid_min_voltagel1 = IntegerField(null=True)
    grid_min_voltagel2 = IntegerField(null=True)
    grid_min_voltagel3 = IntegerField(null=True)
    grid_var_activepower = FloatField(null=True)
    grid_var_currentl1 = IntegerField(null=True)
    grid_var_currentl2 = IntegerField(null=True)
    grid_var_currentl3 = IntegerField(null=True)
    grid_var_freqency = FloatField(null=True)
    grid_var_reactivepower = FloatField(null=True)
    grid_var_voltagel1 = IntegerField(null=True)
    grid_var_voltagel2 = IntegerField(null=True)
    grid_var_voltagel3 = IntegerField(null=True)
    id = IntegerField(null=True)
    pctimestamp = DateTimeField()
    ppmtimestamp = DateTimeField(null=True)
    status_avg_anemometer1_corrgain = FloatField(null=True)
    status_avg_anemometer1_corroffset = FloatField(null=True)
    status_avg_anemometer1_freq = FloatField(null=True)
    status_avg_anemometer1_ms_hz = FloatField(null=True)
    status_avg_anemometer1_offset_ms = FloatField(null=True)
    status_avg_anemometer2_corrgain = FloatField(null=True)
    status_avg_anemometer2_corroffset = FloatField(null=True)
    status_avg_anemometer2_freq = FloatField(null=True)
    status_avg_anemometer2_ms_hz = FloatField(null=True)
    status_avg_anemometer2_offset_ms = FloatField(null=True)
    status_avg_baropress = IntegerField(null=True)
    status_avg_bladeapos = FloatField(null=True)
    status_avg_bladeapress = IntegerField(null=True)
    status_avg_bladebpos = FloatField(null=True)
    status_avg_bladebpress = IntegerField(null=True)
    status_avg_bladecpos = FloatField(null=True)
    status_avg_bladecpress = IntegerField(null=True)
    status_avg_gearoilfiltinpress = FloatField(null=True)
    status_avg_gearoilpress = FloatField(null=True)
    status_avg_generatorrpm = IntegerField(null=True)
    status_avg_hubinletpress = FloatField(null=True)
    status_avg_humiditynacalle = IntegerField(null=True)
    status_avg_humiditytowerbase = IntegerField(null=True)
    status_avg_nacellepos = IntegerField(null=True)
    status_avg_rotorrpm = FloatField(null=True)
    status_avg_shaftbrakepress = IntegerField(null=True)
    status_avg_tipbrakepress = IntegerField(null=True)
    status_avg_winddirection1 = FloatField(null=True)
    status_avg_winddirection2 = FloatField(null=True)
    status_avg_windspeed1 = FloatField(null=True)
    status_avg_windspeed2 = FloatField(null=True)
    status_avg_yawbrakepress = IntegerField(null=True)
    status_errorcode = IntegerField(null=True)
    status_generatoronnet = IntegerField(null=True)
    status_max_baropress = IntegerField(null=True)
    status_max_bladeapos = FloatField(null=True)
    status_max_bladeapress = IntegerField(null=True)
    status_max_bladebpos = FloatField(null=True)
    status_max_bladebpress = IntegerField(null=True)
    status_max_bladecpos = FloatField(null=True)
    status_max_bladecpress = IntegerField(null=True)
    status_max_gearoilfiltinpress = FloatField(null=True)
    status_max_gearoilpress = FloatField(null=True)
    status_max_generatorrpm = IntegerField(null=True)
    status_max_hubinletpress = FloatField(null=True)
    status_max_humiditynacalle = IntegerField(null=True)
    status_max_humiditytowerbase = IntegerField(null=True)
    status_max_nacellepos = IntegerField(null=True)
    status_max_rotorrpm = FloatField(null=True)
    status_max_shaftbrakepress = IntegerField(null=True)
    status_max_tipbrakepress = IntegerField(null=True)
    status_max_winddirection1 = FloatField(null=True)
    status_max_winddirection2 = FloatField(null=True)
    status_max_windspeed1 = FloatField(null=True)
    status_max_windspeed2 = FloatField(null=True)
    status_max_yawbrakepress = IntegerField(null=True)
    status_min_baropress = IntegerField(null=True)
    status_min_bladeapos = FloatField(null=True)
    status_min_bladeapress = IntegerField(null=True)
    status_min_bladebpos = FloatField(null=True)
    status_min_bladebpress = IntegerField(null=True)
    status_min_bladecpos = FloatField(null=True)
    status_min_bladecpress = IntegerField(null=True)
    status_min_gearoilfiltinpress = FloatField(null=True)
    status_min_gearoilpress = FloatField(null=True)
    status_min_generatorrpm = IntegerField(null=True)
    status_min_hubinletpress = FloatField(null=True)
    status_min_humiditynacalle = IntegerField(null=True)
    status_min_humiditytowerbase = IntegerField(null=True)
    status_min_nacellepos = IntegerField(null=True)
    status_min_rotorrpm = FloatField(null=True)
    status_min_shaftbrakepress = IntegerField(null=True)
    status_min_tipbrakepress = IntegerField(null=True)
    status_min_winddirection1 = FloatField(null=True)
    status_min_winddirection2 = FloatField(null=True)
    status_min_windspeed1 = FloatField(null=True)
    status_min_windspeed2 = FloatField(null=True)
    status_min_yawbrakepress = IntegerField(null=True)
    status_var_baropress = IntegerField(null=True)
    status_var_bladeapos = IntegerField(null=True)
    status_var_bladeapress = IntegerField(null=True)
    status_var_bladebpos = IntegerField(null=True)
    status_var_bladebpress = IntegerField(null=True)
    status_var_bladecpos = IntegerField(null=True)
    status_var_bladecpress = IntegerField(null=True)
    status_var_gearoilfiltinpress = IntegerField(null=True)
    status_var_gearoilpress = IntegerField(null=True)
    status_var_generatorrpm = IntegerField(null=True)
    status_var_hubinletpress = IntegerField(null=True)
    status_var_humiditynacalle = IntegerField(null=True)
    status_var_humiditytowerbase = IntegerField(null=True)
    status_var_nacellepos = IntegerField(null=True)
    status_var_rotorrpm = FloatField(null=True)
    status_var_shaftbrakepress = IntegerField(null=True)
    status_var_tipbrakepress = IntegerField(null=True)
    status_var_winddirection1 = IntegerField(null=True)
    status_var_winddirection2 = IntegerField(null=True)
    status_var_windspeed1 = FloatField(null=True)
    status_var_windspeed2 = FloatField(null=True)
    status_var_yawbrakepress = IntegerField(null=True)
    temp_avg_ambient = IntegerField(null=True)
    temp_avg_auxtransformer = IntegerField(null=True)
    temp_avg_controlpanel = IntegerField(null=True)
    temp_avg_convertergenside1 = IntegerField(null=True)
    temp_avg_convertergenside2 = IntegerField(null=True)
    temp_avg_convertergridside1 = IntegerField(null=True)
    temp_avg_convertergridside2 = IntegerField(null=True)
    temp_avg_converterpanel = IntegerField(null=True)
    temp_avg_gearbearfront = IntegerField(null=True)
    temp_avg_gearbearrear = IntegerField(null=True)
    temp_avg_gearoil = IntegerField(null=True)
    temp_avg_gearoilaftexch = IntegerField(null=True)
    temp_avg_gearoilfilter = IntegerField(null=True)
    temp_avg_genbearingfront = IntegerField(null=True)
    temp_avg_genbearingrear = IntegerField(null=True)
    temp_avg_generator1 = IntegerField(null=True)
    temp_avg_generator2 = IntegerField(null=True)
    temp_avg_hubpanel = IntegerField(null=True)
    temp_avg_mainbearing1 = IntegerField(null=True)
    temp_avg_mainpanel = IntegerField(null=True)
    temp_avg_nacelle = IntegerField(null=True)
    temp_avg_operation_panel = IntegerField(null=True)
    temp_avg_phasecomppanel = IntegerField(null=True)
    temp_avg_pitchoil = IntegerField(null=True)
    temp_avg_slipringbox = IntegerField(null=True)
    temp_avg_tempgencable = IntegerField(null=True)
    temp_avg_thyristor = IntegerField(null=True)
    temp_avg_topbox = IntegerField(null=True)
    temp_avg_tower = IntegerField(null=True)
    temp_avg_towerbase = IntegerField(null=True)
    temp_avg_transformer = IntegerField(null=True)
    temp_avg_transformerroom = IntegerField(null=True)
    temp_avg_transformerw1 = IntegerField(null=True)
    temp_avg_transformerw2 = IntegerField(null=True)
    temp_avg_transformerw3 = IntegerField(null=True)
    temp_avg_w1generator1 = IntegerField(null=True)
    temp_avg_w1generator2 = IntegerField(null=True)
    temp_avg_w2generator1 = IntegerField(null=True)
    temp_avg_w2generator2 = IntegerField(null=True)
    temp_avg_w3generator1 = IntegerField(null=True)
    temp_avg_w3generator2 = IntegerField(null=True)
    temp_avg_wateraftcooler = IntegerField(null=True)
    temp_avg_waterbefcooler = IntegerField(null=True)
    temp_avg_yawrim = IntegerField(null=True)
    temp_max_ambient = IntegerField(null=True)
    temp_max_auxtransformer = IntegerField(null=True)
    temp_max_controlpanel = IntegerField(null=True)
    temp_max_convertergenside1 = IntegerField(null=True)
    temp_max_convertergenside2 = IntegerField(null=True)
    temp_max_convertergridside1 = IntegerField(null=True)
    temp_max_convertergridside2 = IntegerField(null=True)
    temp_max_converterpanel = IntegerField(null=True)
    temp_max_gearbearfront = IntegerField(null=True)
    temp_max_gearbearrear = IntegerField(null=True)
    temp_max_gearoil = IntegerField(null=True)
    temp_max_gearoilaftexch = IntegerField(null=True)
    temp_max_gearoilfilter = IntegerField(null=True)
    temp_max_genbearingfront = IntegerField(null=True)
    temp_max_genbearingrear = IntegerField(null=True)
    temp_max_generator1 = IntegerField(null=True)
    temp_max_generator2 = IntegerField(null=True)
    temp_max_hubpanel = IntegerField(null=True)
    temp_max_mainbearing1 = IntegerField(null=True)
    temp_max_mainpanel = IntegerField(null=True)
    temp_max_nacelle = IntegerField(null=True)
    temp_max_operation_panel = IntegerField(null=True)
    temp_max_phasecomppanel = IntegerField(null=True)
    temp_max_pitchoil = IntegerField(null=True)
    temp_max_slipringbox = IntegerField(null=True)
    temp_max_tempgencable = IntegerField(null=True)
    temp_max_thyristor = IntegerField(null=True)
    temp_max_topbox = IntegerField(null=True)
    temp_max_tower = IntegerField(null=True)
    temp_max_towerbase = IntegerField(null=True)
    temp_max_transformer = IntegerField(null=True)
    temp_max_transformerroom = IntegerField(null=True)
    temp_max_transformerw1 = IntegerField(null=True)
    temp_max_transformerw2 = IntegerField(null=True)
    temp_max_transformerw3 = IntegerField(null=True)
    temp_max_w1generator1 = IntegerField(null=True)
    temp_max_w1generator2 = IntegerField(null=True)
    temp_max_w2generator1 = IntegerField(null=True)
    temp_max_w2generator2 = IntegerField(null=True)
    temp_max_w3generator1 = IntegerField(null=True)
    temp_max_w3generator2 = IntegerField(null=True)
    temp_max_wateraftcooler = IntegerField(null=True)
    temp_max_waterbefcooler = IntegerField(null=True)
    temp_max_yawrim = IntegerField(null=True)
    temp_min_ambient = IntegerField(null=True)
    temp_min_auxtransformer = IntegerField(null=True)
    temp_min_controlpanel = IntegerField(null=True)
    temp_min_convertergenside1 = IntegerField(null=True)
    temp_min_convertergenside2 = IntegerField(null=True)
    temp_min_convertergridside1 = IntegerField(null=True)
    temp_min_convertergridside2 = IntegerField(null=True)
    temp_min_converterpanel = IntegerField(null=True)
    temp_min_gearbearfront = IntegerField(null=True)
    temp_min_gearbearrear = IntegerField(null=True)
    temp_min_gearoil = IntegerField(null=True)
    temp_min_gearoilaftexch = IntegerField(null=True)
    temp_min_gearoilfilter = IntegerField(null=True)
    temp_min_genbearingfront = IntegerField(null=True)
    temp_min_genbearingrear = IntegerField(null=True)
    temp_min_generator1 = IntegerField(null=True)
    temp_min_generator2 = IntegerField(null=True)
    temp_min_hubpanel = IntegerField(null=True)
    temp_min_mainbearing1 = IntegerField(null=True)
    temp_min_mainpanel = IntegerField(null=True)
    temp_min_nacelle = IntegerField(null=True)
    temp_min_operation_panel = IntegerField(null=True)
    temp_min_phasecomppanel = IntegerField(null=True)
    temp_min_pitchoil = IntegerField(null=True)
    temp_min_slipringbox = IntegerField(null=True)
    temp_min_tempgencable = IntegerField(null=True)
    temp_min_thyristor = IntegerField(null=True)
    temp_min_topbox = IntegerField(null=True)
    temp_min_tower = IntegerField(null=True)
    temp_min_towerbase = IntegerField(null=True)
    temp_min_transformer = IntegerField(null=True)
    temp_min_transformerroom = IntegerField(null=True)
    temp_min_transformerw1 = IntegerField(null=True)
    temp_min_transformerw2 = IntegerField(null=True)
    temp_min_transformerw3 = IntegerField(null=True)
    temp_min_w1generator1 = IntegerField(null=True)
    temp_min_w1generator2 = IntegerField(null=True)
    temp_min_w2generator1 = IntegerField(null=True)
    temp_min_w2generator2 = IntegerField(null=True)
    temp_min_w3generator1 = IntegerField(null=True)
    temp_min_w3generator2 = IntegerField(null=True)
    temp_min_wateraftcooler = IntegerField(null=True)
    temp_min_waterbefcooler = IntegerField(null=True)
    temp_min_yawrim = IntegerField(null=True)
    ttimestamp = DateTimeField(null=True)

    class Meta:
        table_name = "magana_10mindata"
        indexes = ((("aero_id", "pctimestamp"), True),)
        primary_key = CompositeKey("aero_id", "pctimestamp")
